==> eiffelstudio-19.05.10.3187.tar: F_code/C22/dt1086.c <==
/*
 * Code for class DT_DATE_TIME_DURATION
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "dt1086.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DT_DATE_TIME_DURATION}.make_precise */
void F1965_19242 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4, EIF_INTEGER_32 arg5, EIF_INTEGER_32 arg6, EIF_INTEGER_32 arg7)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	F1962_19167(Current, arg1, arg2, arg3);
	F1959_19084(Current, arg4, arg5, arg6, arg7);
	RTLE;
}

/* {DT_DATE_TIME_DURATION}.make_canonical_from_dates */
void F1965_19249 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc6 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc7 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc8 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc9 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc10 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc11 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc12 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg2);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	loc1 = F1963_19200(RTCW(arg2));
	ti4_1 = F1963_19200(RTCW(arg1));
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 - ti4_1);
	loc2 = F1963_19201(RTCW(arg2));
	ti4_1 = F1963_19201(RTCW(arg1));
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ti4_1);
	loc10 = F1963_19202(RTCW(arg2));
	loc9 = F1963_19202(RTCW(arg1));
	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc10 - loc9);
	loc4 = F1960_19127(RTCW(arg2));
	ti4_1 = F1960_19127(RTCW(arg1));
	loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 - ti4_1);
	tb1 = F1966_19283(RTCW(arg1), arg2);
	if (tb1) {
		if ((EIF_BOOLEAN) (loc4 < ((EIF_INTEGER_32) 0L))) {
			loc3--;
			loc4 += ((EIF_INTEGER_32) 86400000L);
		}
		loc8 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 1000L));
		loc4 /= ((EIF_INTEGER_32) 1000L);
		loc7 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 60L));
		loc4 /= ((EIF_INTEGER_32) 60L);
		loc6 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 60L));
		loc5 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 / ((EIF_INTEGER_32) 60L));
		if ((EIF_BOOLEAN) (loc3 < ((EIF_INTEGER_32) 0L))) {
			loc2--;
			loc11 = F1963_19211(RTCW(arg2));
			if ((EIF_BOOLEAN) (loc11 < loc9)) {
				loc3 += loc9;
			} else {
				loc3 += loc11;
			}
		}
		if ((EIF_BOOLEAN) (loc2 < ((EIF_INTEGER_32) 0L))) {
			loc1--;
			loc2 += ((EIF_INTEGER_32) 12L);
		}
	} else {
		if ((EIF_BOOLEAN) (loc4 > ((EIF_INTEGER_32) 0L))) {
			loc3++;
			loc4 -= ((EIF_INTEGER_32) 86400000L);
		}
		loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) -loc4;
		loc8 = (EIF_INTEGER_32) (EIF_INTEGER_32) -(EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 1000L));
		loc4 /= ((EIF_INTEGER_32) 1000L);
		loc7 = (EIF_INTEGER_32) (EIF_INTEGER_32) -(EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 60L));
		loc4 /= ((EIF_INTEGER_32) 60L);
		loc6 = (EIF_INTEGER_32) (EIF_INTEGER_32) -(EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 60L));
		loc5 = (EIF_INTEGER_32) (EIF_INTEGER_32) -(EIF_INTEGER_32) (loc4 / ((EIF_INTEGER_32) 60L));
		loc12 = F1963_19210(RTCW(arg2));
		if ((EIF_BOOLEAN) (loc3 > ((EIF_INTEGER_32) 0L))) {
			loc2++;
			loc3 -= loc12;
		} else {
			if ((EIF_BOOLEAN) (loc12 < loc9)) {
				loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc3 + loc9) - loc12);
			}
		}
		if ((EIF_BOOLEAN) (loc2 > ((EIF_INTEGER_32) 0L))) {
			loc1++;
			loc2 -= ((EIF_INTEGER_32) 12L);
		}
	}
	F1965_19242(Current, loc1, loc2, loc3, loc5, loc6, loc7, loc8);
	RTLE;
}

/* {DT_DATE_TIME_DURATION}.hash_code */
EIF_INTEGER_32 F1965_19254 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	Result = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_4_);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_5_);
	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_6_);
	ti4_3 = F1959_19093(Current);
	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) ((EIF_INTEGER_32) (Result + (EIF_INTEGER_32) (ti4_1 * ((EIF_INTEGER_32) 31L))) + (EIF_INTEGER_32) (ti4_2 * ((EIF_INTEGER_32) 365L))) + ti4_3);
	if ((EIF_BOOLEAN) (Result < ((EIF_INTEGER_32) 0L))) {
		Result = (EIF_INTEGER_32) (EIF_INTEGER_32) -(EIF_INTEGER_32) (Result + ((EIF_INTEGER_32) 1L));
	}
	RTLE;
	return Result;
}

/* {DT_DATE_TIME_DURATION}.date_time */
EIF_REFERENCE F1965_19255 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	
	
	tr1 = F1386_13133(RTCW(arg1), Current);
	return (EIF_REFERENCE) tr1;
}

/* {DT_DATE_TIME_DURATION}.set_canonical */
void F1965_19256 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	loc1 = RTOUCR(119,F1965_19267, (Current));
	F1963_19215(RTCW(loc1), arg1);
	F1960_19133(RTCW(loc1), arg1);
	F1966_19278(RTCW(loc1), Current);
	F1965_19249(Current, arg1, loc1);
	RTLE;
}

/* {DT_DATE_TIME_DURATION}.is_equal */
EIF_BOOLEAN F1965_19264 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = RTOUCR(90,F1165_10418, (Current));
	tb1 = F31_402(RTCW(tr1), Current, arg1);
	if (tb1) {
		RTLE;
		return (EIF_BOOLEAN) F1965_19265(Current, arg1);
	}
	RTLE;
	return (EIF_BOOLEAN) 0;
}

/* {DT_DATE_TIME_DURATION}.same_date_time_duration */
EIF_BOOLEAN F1965_19265 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_6_);
	ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_5_);
	if ((EIF_BOOLEAN)((EIF_INTEGER_32) ((EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_6_) - ti4_1) * ((EIF_INTEGER_32) 12L)) + (EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_5_) - ti4_2)) == ((EIF_INTEGER_32) 0L))) {
		loc2 = F1959_19093(Current);
		ti4_1 = F1959_19093(RTCW(arg1));
		loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ti4_1);
		if ((EIF_BOOLEAN) (loc2 < ((EIF_INTEGER_32) 0L))) {
			loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) -loc2;
			loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_4_);
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_4_);
			loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc1 - ti4_1) - (EIF_INTEGER_32) (loc2 / ((EIF_INTEGER_32) 86400000L)));
			loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) -(EIF_INTEGER_32) (loc2 % ((EIF_INTEGER_32) 86400000L));
		} else {
			loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_4_);
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_4_);
			loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc1 - ti4_1) + (EIF_INTEGER_32) (loc2 / ((EIF_INTEGER_32) 86400000L)));
			loc2 %= ((EIF_INTEGER_32) 86400000L);
		}
		RTLE;
		return (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN)(loc2 == ((EIF_INTEGER_32) 0L)) && (EIF_BOOLEAN)(loc1 == ((EIF_INTEGER_32) 0L)));
	}
	RTLE;
	return (EIF_BOOLEAN) 0;
}

/* {DT_DATE_TIME_DURATION}.tmp_date_time */
static EIF_REFERENCE F1965_19267_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(119)

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOTP;
	tr1 = RTLNS(eif_new_type(1965, 0x01).id, 1965, _OBJSIZ_0_0_0_2_0_0_0_0_);
	F1966_19268(RTCW(tr1), ((EIF_INTEGER_32) 1L), ((EIF_INTEGER_32) 1L), ((EIF_INTEGER_32) 1L), ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTOTE;
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1965_19267 (EIF_REFERENCE Current)
{
	GTCX
	return RTOUCR(119,F1965_19267_body,(Current));
}

void EIF_Minit1086 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-25.12.9.8922.tar: F_code/C22/dt1086.c <==
/*
 * Code for class DT_DATE_TIME_DURATION
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "dt1086.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DT_DATE_TIME_DURATION}.make_precise */
void F2035_21243 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4, EIF_INTEGER_32 arg5, EIF_INTEGER_32 arg6, EIF_INTEGER_32 arg7)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	F2032_21165(Current, arg1, arg2, arg3);
	F2029_21082(Current, arg4, arg5, arg6, arg7);
	RTLE;
}

/* {DT_DATE_TIME_DURATION}.make_canonical_from_dates */
void F2035_21250 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc6 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc7 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc8 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc9 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc10 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc11 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc12 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg2);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	loc1 = F2033_21198(RTCW(arg2));
	ti4_1 = F2033_21198(RTCW(arg1));
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 - ti4_1);
	loc2 = F2033_21199(RTCW(arg2));
	ti4_1 = F2033_21199(RTCW(arg1));
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ti4_1);
	loc10 = F2033_21200(RTCW(arg2));
	loc9 = F2033_21200(RTCW(arg1));
	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc10 - loc9);
	loc4 = F2030_21125(RTCW(arg2));
	ti4_1 = F2030_21125(RTCW(arg1));
	loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 - ti4_1);
	tb1 = F2036_21284(RTCW(arg1), arg2);
	if (tb1) {
		if ((EIF_BOOLEAN) (loc4 < ((EIF_INTEGER_32) 0L))) {
			loc3--;
			loc4 += ((EIF_INTEGER_32) 86400000L);
		}
		loc8 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 1000L));
		loc4 /= ((EIF_INTEGER_32) 1000L);
		loc7 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 60L));
		loc4 /= ((EIF_INTEGER_32) 60L);
		loc6 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 60L));
		loc5 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 / ((EIF_INTEGER_32) 60L));
		if ((EIF_BOOLEAN) (loc3 < ((EIF_INTEGER_32) 0L))) {
			loc2--;
			loc11 = F2033_21209(RTCW(arg2));
			if ((EIF_BOOLEAN) (loc11 < loc9)) {
				loc3 += loc9;
			} else {
				loc3 += loc11;
			}
		}
		if ((EIF_BOOLEAN) (loc2 < ((EIF_INTEGER_32) 0L))) {
			loc1--;
			loc2 += ((EIF_INTEGER_32) 12L);
		}
	} else {
		if ((EIF_BOOLEAN) (loc4 > ((EIF_INTEGER_32) 0L))) {
			loc3++;
			loc4 -= ((EIF_INTEGER_32) 86400000L);
		}
		loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) -loc4;
		loc8 = (EIF_INTEGER_32) (EIF_INTEGER_32) -(EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 1000L));
		loc4 /= ((EIF_INTEGER_32) 1000L);
		loc7 = (EIF_INTEGER_32) (EIF_INTEGER_32) -(EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 60L));
		loc4 /= ((EIF_INTEGER_32) 60L);
		loc6 = (EIF_INTEGER_32) (EIF_INTEGER_32) -(EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 60L));
		loc5 = (EIF_INTEGER_32) (EIF_INTEGER_32) -(EIF_INTEGER_32) (loc4 / ((EIF_INTEGER_32) 60L));
		loc12 = F2033_21208(RTCW(arg2));
		if ((EIF_BOOLEAN) (loc3 > ((EIF_INTEGER_32) 0L))) {
			loc2++;
			loc3 -= loc12;
		} else {
			if ((EIF_BOOLEAN) (loc12 < loc9)) {
				loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc3 + loc9) - loc12);
			}
		}
		if ((EIF_BOOLEAN) (loc2 > ((EIF_INTEGER_32) 0L))) {
			loc1++;
			loc2 -= ((EIF_INTEGER_32) 12L);
		}
	}
	F2035_21243(Current, loc1, loc2, loc3, loc5, loc6, loc7, loc8);
	RTLE;
}

/* {DT_DATE_TIME_DURATION}.hash_code */
EIF_INTEGER_32 F2035_21255 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	Result = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_4_);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_5_);
	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_6_);
	ti4_3 = F2029_21091(Current);
	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) ((EIF_INTEGER_32) (Result + (EIF_INTEGER_32) (ti4_1 * ((EIF_INTEGER_32) 31L))) + (EIF_INTEGER_32) (ti4_2 * ((EIF_INTEGER_32) 365L))) + ti4_3);
	if ((EIF_BOOLEAN) (Result < ((EIF_INTEGER_32) 0L))) {
		RTLE;
		return (EIF_INTEGER_32) (EIF_INTEGER_32) -(EIF_INTEGER_32) (Result + ((EIF_INTEGER_32) 1L));
	}
	RTLE;
	return Result;
}

/* {DT_DATE_TIME_DURATION}.date_time */
EIF_REFERENCE F2035_21256 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	
	
	tr1 = F1384_14231(RTCW(arg1), Current);
	return (EIF_REFERENCE) tr1;
}

/* {DT_DATE_TIME_DURATION}.set_canonical */
void F2035_21257 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	loc1 = RTOUCR(1648,F2035_21268, (Current));
	F2033_21213(RTCW(loc1), arg1);
	F2030_21131(RTCW(loc1), arg1);
	F2036_21279(RTCW(loc1), Current);
	F2035_21250(Current, arg1, loc1);
	RTLE;
}

/* {DT_DATE_TIME_DURATION}.is_equal */
EIF_BOOLEAN F2035_21265 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = RTOUCR(92,F1021_9580, (Current));
	tb1 = F32_323(RTCW(tr1), Current, arg1);
	if (tb1) {
		RTLE;
		return (EIF_BOOLEAN) F2035_21266(Current, arg1);
	}
	RTLE;
	return (EIF_BOOLEAN) 0;
}

/* {DT_DATE_TIME_DURATION}.same_date_time_duration */
EIF_BOOLEAN F2035_21266 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_6_);
	ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_5_);
	if ((EIF_BOOLEAN)((EIF_INTEGER_32) ((EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_6_) - ti4_1) * ((EIF_INTEGER_32) 12L)) + (EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_5_) - ti4_2)) == ((EIF_INTEGER_32) 0L))) {
		loc2 = F2029_21091(Current);
		ti4_1 = F2029_21091(RTCW(arg1));
		loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ti4_1);
		if ((EIF_BOOLEAN) (loc2 < ((EIF_INTEGER_32) 0L))) {
			loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) -loc2;
			loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_4_);
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_4_);
			loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc1 - ti4_1) - (EIF_INTEGER_32) (loc2 / ((EIF_INTEGER_32) 86400000L)));
			loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) -(EIF_INTEGER_32) (loc2 % ((EIF_INTEGER_32) 86400000L));
		} else {
			loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_4_);
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_4_);
			loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc1 - ti4_1) + (EIF_INTEGER_32) (loc2 / ((EIF_INTEGER_32) 86400000L)));
			loc2 %= ((EIF_INTEGER_32) 86400000L);
		}
		RTLE;
		return (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN)(loc2 == ((EIF_INTEGER_32) 0L)) && (EIF_BOOLEAN)(loc1 == ((EIF_INTEGER_32) 0L)));
	}
	RTLE;
	return (EIF_BOOLEAN) 0;
}

/* {DT_DATE_TIME_DURATION}.tmp_date_time */
static EIF_REFERENCE F2035_21268_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(1648)

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOTP;
	tr1 = RTLNS(eif_new_type(2035, 0x01).id, 2035, _OBJSIZ_0_0_0_2_0_0_0_0_);
	F2036_21269(RTCW(tr1), ((EIF_INTEGER_32) 1L), ((EIF_INTEGER_32) 1L), ((EIF_INTEGER_32) 1L), ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTOTE;
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F2035_21268 (EIF_REFERENCE Current)
{
	GTCX
	return RTOUCR(1648,F2035_21268_body,(Current));
}

void EIF_Minit1086 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
